@@ -9,32 +9,46 @@ use Math::Expression::Evaluator;
 use Data::Dumper;
 
 my $statement = '2 + a + 5 + (3+4)';
-
-my $test = Math::Expression::Evaluator->new($statement);
-print Dumper $test->{ast};
-$test->optimize;
-print Dumper $test->{ast};
+my $iterations = $ARGV[0] || 200;
 
 sub with_optimize {
-    my $count = shift || confess "foo";
     my $m = Math::Expression::Evaluator->new($statement);
     $m->optimize;
-    for (1..$count){
+    for (1..$iterations){
         $m->val({a => $_});
     }
 }
 
 sub no_optimize {
-    my $count = shift || confess "foo";
     my $m = Math::Expression::Evaluator->new($statement);
-    for (1..$count){
+    for (1..$iterations){
         $m->val({a => $_});
     }
 }
 
+sub compiled {
+    my $m = Math::Expression::Evaluator->new($statement);
+    my $c = $m->compiled();
+    for (1..$iterations){
+        $c->({a => $_});
+    }
+}
+
+sub opt_compiled {
+    my $m = Math::Expression::Evaluator->new($statement);
+    $m->optimize();
+    my $c = $m->compiled();
+    for (1..$iterations){
+        $c->({a => $_});
+    }
+}
+
+
 my %tests = (
-        optimize       => sub { with_optimize(10) },
-        no_optimize    => sub { no_optimize(10) },
+        optimize       => \&with_optimize,
+        no_optimize    => \&no_optimize,
+        compiled       => \&compiled,
+        opt_compiled   => \&opt_compiled,
 );
 #for (100,1000,10000){
 #    print $_, "\n";
